"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SQLiteSpan = void 0;
const adapter_base_1 = require("@graphql-debugger/adapter-base");
const time_1 = require("@graphql-debugger/time");
const utils_1 = require("@graphql-debugger/utils");
const build_1 = require("../../../../schemas/build");
const prisma_1 = require("../prisma");
class SQLiteSpan extends adapter_base_1.BaseSpan {
    constructor() {
        super();
    }
    async findMany({ where, }) {
        let _where = {};
        if (where.spanIds) {
            _where = { ..._where, ...{ spanId: { in: where.spanIds } } };
        }
        if (where.traceIds) {
            _where = { ..._where, ...{ traceId: { in: where.traceIds } } };
        }
        if (where.isGraphQLRootSpan) {
            _where = { ..._where, ...{ isGraphQLRootSpan: true } };
        }
        const spans = await prisma_1.prisma.span.findMany({
            where: _where,
        });
        const response = {
            spans: spans.map((span) => (0, utils_1.dbSpanToNetwork)(span)),
        };
        const parsed = build_1.ListSpansResponseSchema.parse(response);
        return parsed;
    }
    async aggregate({ where, }) {
        const spans = await prisma_1.prisma.span.findMany({
            where: {
                traceGroup: {
                    schemaId: where.schemaId,
                },
                name: where.name,
            },
        });
        const _spans = spans.map((span) => (0, utils_1.dbSpanToNetwork)(span));
        const response = {
            resolveCount: _spans.length,
            errorCount: _spans.filter((s) => s.errorMessage || s.errorStack).length,
            averageDuration: (() => {
                if (_spans.length === 0) {
                    return "0";
                }
                const durations = _spans.map((s) => new time_1.UnixNanoTimeStamp(BigInt(s.durationNano)));
                const average = time_1.UnixNanoTimeStamp.average(durations);
                return average.toString();
            })(),
            lastResolved: (() => {
                if (_spans.length === 0) {
                    return "0";
                }
                const timestamps = _spans.map((s) => new time_1.UnixNanoTimeStamp(BigInt(s.endTimeUnixNano)));
                const max = time_1.UnixNanoTimeStamp.latest(timestamps);
                return max.toString();
            })(),
            spans: _spans,
        };
        const parsed = build_1.AggregateSpansResponseSchema.parse(response);
        return parsed;
    }
    async createOne({ input, }) {
        const startTimeUnixNano = time_1.UnixNanoTimeStamp.fromString(input.startTimeUnixNano);
        const endTimeUnixNano = time_1.UnixNanoTimeStamp.fromString(input.endTimeUnixNano);
        const durationNano = time_1.UnixNanoTimeStamp.duration(startTimeUnixNano, endTimeUnixNano);
        const span = await prisma_1.prisma.span.create({
            data: {
                spanId: input.spanId,
                parentSpanId: input.parentSpanId,
                name: input.name,
                kind: input.kind.toString(),
                startTimeUnixNano: startTimeUnixNano.toStorage(),
                endTimeUnixNano: endTimeUnixNano.toStorage(),
                durationNano: durationNano.toStorage(),
                traceId: input.traceId,
                traceGroupId: input.traceGroupId,
                errorMessage: input.errorMessage,
                errorStack: input.errorStack,
                graphqlDocument: input.graphqlDocument,
                graphqlVariables: input.graphqlVariables,
                graphqlResult: input.graphqlResult,
                graphqlContext: input.graphqlContext,
                graphqlSchemaHash: input.graphqlSchemaHash,
                graphqlOperationName: input.graphqlOperationName,
                graphqlOperationType: input.graphqlOperationType,
                isForeign: input.isForeign || false,
                isGraphQLRootSpan: input.isGraphQLRootSpan || false,
                attributes: JSON.stringify(input.attributes),
            },
        });
        const response = {
            span: (0, utils_1.dbSpanToNetwork)(span),
        };
        const parsed = build_1.CreateSpanResponseSchema.parse(response);
        return parsed;
    }
    async deleteOne({ where, }) {
        await prisma_1.prisma.span.delete({
            where: {
                id: where.id,
            },
        });
        const response = {
            success: true,
        };
        const parsed = build_1.DeleteSpanResponseSchema.parse(response);
        return parsed;
    }
}
exports.SQLiteSpan = SQLiteSpan;
