"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SQLiteTrace = void 0;
const adapter_base_1 = require("@graphql-debugger/adapter-base");
const utils_1 = require("@graphql-debugger/utils");
const build_1 = require("../../../../schemas/build");
const prisma_1 = require("../prisma");
class SQLiteTrace extends adapter_base_1.BaseTrace {
    constructor() {
        super();
    }
    async findFirst({ where, options, }) {
        const trace = await prisma_1.prisma.traceGroup.findFirst({
            where: {
                traceId: where.traceId,
            },
            include: {
                ...(options?.includeSpans
                    ? {
                        spans: true,
                    }
                    : {}),
            },
        });
        if (!trace) {
            return null;
        }
        const spans = (trace?.spans || []).map((span) => (0, utils_1.dbSpanToNetwork)(span));
        const rootSpan = spans.find((span) => span.isGraphQLRootSpan);
        const response = {
            id: trace.id,
            traceId: trace.traceId,
            ...(options?.includeSpans
                ? {
                    spans,
                    rootSpan,
                }
                : {
                    spans: [],
                }),
        };
        const parsed = build_1.TraceSchema.parse(response);
        return parsed;
    }
    async findMany(args) {
        const whereConditions = [
            {
                spans: {
                    some: {
                        isGraphQLRootSpan: true,
                    },
                },
            },
        ];
        if (args.where?.id) {
            whereConditions.push({ id: args.where.id });
        }
        if (args.where?.schemaId) {
            whereConditions.push({ schemaId: args.where.schemaId });
        }
        if (args.where?.rootSpanName) {
            whereConditions.push({
                spans: {
                    some: {
                        name: {
                            equals: args.where.rootSpanName,
                        },
                    },
                },
            });
        }
        if (args.where?.traceIds) {
            whereConditions.push({ traceId: { in: args.where.traceIds } });
        }
        const where = {
            AND: whereConditions,
        };
        const traces = await prisma_1.prisma.traceGroup.findMany({
            orderBy: { createdAt: "desc" },
            where,
            take: 20,
            include: {
                ...(args.includeSpans
                    ? {
                        spans: true,
                    }
                    : {}),
            },
        });
        const response = traces.map((trace) => {
            const spans = (trace?.spans || []).map((span) => (0, utils_1.dbSpanToNetwork)(span));
            return {
                id: trace.id,
                traceId: trace.traceId,
                schemaId: trace.schemaId,
                spans,
                rootSpan: spans.find((span) => span.isGraphQLRootSpan),
            };
        });
        const parsed = build_1.TraceSchema.array().parse(response);
        return parsed;
    }
    async createOne({ input, }) {
        const trace = await prisma_1.prisma.traceGroup.create({
            data: {
                traceId: input.traceId,
                schemaId: input.schemaId,
            },
        });
        const response = {
            trace: {
                id: trace.id,
                traceId: trace.traceId,
                schemaId: trace.schemaId,
                spans: [],
            },
        };
        const parsed = build_1.CreateTraceResponseSchema.parse(response);
        return parsed;
    }
    async updateOne({ where, input, }) {
        const schema = await prisma_1.prisma.schema.findFirst({
            where: {
                id: input.schemaId,
            },
        });
        if (!schema) {
            throw new Error("Schema not found");
        }
        const trace = await prisma_1.prisma.traceGroup.update({
            where: {
                id: where.id,
            },
            data: {
                schemaId: input.schemaId,
            },
        });
        if (!trace) {
            throw new Error("Trace not found");
        }
        const response = {
            trace: {
                id: trace.id,
                traceId: trace.traceId,
                schemaId: trace.schemaId,
                spans: [],
            },
        };
        const parsed = build_1.UpdateTraceResponseSchema.parse(response);
        return parsed;
    }
}
exports.SQLiteTrace = SQLiteTrace;
